@@ -1,18 +1,18 @@
 ;(function(){
   var map = {
-  "commitId": "10da76a143bf18dfe4c2bac0a7694992b4b25eb9",
-  "branchName": "release-client-6.5.x",
-  "buildTime": "2025-07-11 05:26:24 GMT",
-  "buildVersion": "1.0.4088",
+  "commitId": "6e0154e293e7e87ab6995962433047a370162b6b",
+  "branchName": "release-client-6.1.x",
+  "buildTime": "2024-08-15 08:46:31 GMT",
+  "buildVersion": "1.0.785",
   "css": [
-    "@zoom/client-calendar-desktop/static/css/chunk-vendors.766c9988.css",
-    "@zoom/client-calendar-desktop/static/css/app.c556d430.css"
+    "@zoom/client-scheduler/static/css/chunk-vendors.87ac9d21.css",
+    "@zoom/client-scheduler/static/css/index.f88b3c61.css"
   ],
   "js": [
-    "@zoom/client-calendar-desktop/static/js/chunk-vendors.7301b4b7.js",
-    "@zoom/client-calendar-desktop/static/js/app.fc849c50.js"
+    "@zoom/client-scheduler/chunk-vendors.73353ab93af9d2d4c1ad.js",
+    "@zoom/client-scheduler/index.73353ab93af9d2d4c1ad.js"
   ],
-  "key": "@zoom/client-calendar-desktop"
+  "key": "clientSchedulerResource"
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
   map.css && map.css.forEach(function (cssItem) {
